==> react-bootstrap-0.2.0.tgz: package/es/components/Icon/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import iconSizes from '../../utils/iconSizes';

var Icon = function Icon(_ref) {
  var _cn;

  var name = _ref.name,
      size = _ref.size,
      rotate = _ref.rotate,
      fixedWidth = _ref.fixedWidth,
      spin = _ref.spin,
      pulse = _ref.pulse,
      className = _ref.className,
      props = _objectWithoutProperties(_ref, ['name', 'size', 'rotate', 'fixedWidth', 'spin', 'pulse', 'className']);

  return React.createElement('i', _extends({}, props, {
    className: cn('fa', 'fa-' + name, (_cn = {
      'fa-fw': fixedWidth,
      'fa-spin': spin,
      'fa-pulse': pulse
    }, _cn['fa-' + size] = size, _cn['fa-rotate-' + rotate] = rotate, _cn), className)
  }));
};

Icon.propTypes = process.env.NODE_ENV !== "production" ? {
  name: PropTypes.string,
  size: PropTypes.oneOf(iconSizes),
  rotate: PropTypes.oneOf(['', '90', '180', '270']),
  fixedWidth: PropTypes.bool,
  spin: PropTypes.bool,
  pulse: PropTypes.bool,
  className: PropTypes.string
} : {};

Icon.defaultProps = {
  name: 'question',
  size: '',
  rotate: '',
  fixedWidth: false,
  spin: false,
  pulse: false,
  className: ''
};

export default Icon;

==> react-bootstrap-0.3.0.tgz: package/es/components/Icon/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import iconSizes from '../../utils/iconSizes';

var Icon = function Icon(_ref) {
  var _cn;

  var name = _ref.name,
      size = _ref.size,
      rotate = _ref.rotate,
      fixedWidth = _ref.fixedWidth,
      spin = _ref.spin,
      pulse = _ref.pulse,
      props = _objectWithoutProperties(_ref, ['name', 'size', 'rotate', 'fixedWidth', 'spin', 'pulse']);

  return React.createElement('i', _extends({}, props, {
    className: cn('fa', 'fa-' + name, (_cn = {
      'fa-fw': fixedWidth,
      'fa-spin': spin,
      'fa-pulse': pulse
    }, _cn['fa-' + size] = size, _cn['fa-rotate-' + rotate] = rotate, _cn), props.className)
  }));
};

Icon.propTypes = process.env.NODE_ENV !== "production" ? {
  name: PropTypes.string,
  size: PropTypes.oneOf(iconSizes),
  rotate: PropTypes.oneOf(['', '90', '180', '270']),
  fixedWidth: PropTypes.bool,
  spin: PropTypes.bool,
  pulse: PropTypes.bool
} : {};

Icon.defaultProps = {
  name: 'question',
  size: '',
  rotate: '',
  fixedWidth: false,
  spin: false,
  pulse: false
};

export default Icon;
